@@ -27,6 +27,7 @@ def is_file_consistent(local_path_file, md5_hash):
 
 
 def get_parser():
+    """Return the parser object for this script."""
     from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter
     parser = ArgumentParser(description=__doc__,
                             formatter_class=ArgumentDefaultsHelpFormatter)
@@ -34,21 +35,22 @@ def get_parser():
 
 
 def main():
+    """Main part of the download script."""
     # Read config file. This has to get updated via git
-    PROJECT_ROOT = utils.get_project_root()
-    infofile = os.path.join(PROJECT_ROOT, "raw-datasets/info.yml")
+    project_root = utils.get_project_root()
+    infofile = os.path.join(project_root, "raw-datasets/info.yml")
     logging.info("Read '%s'...", infofile)
     with open(infofile, 'r') as ymlfile:
         datasets = yaml.load(ymlfile)
     for dataset in datasets:
-        local_path_file = os.path.join(PROJECT_ROOT, dataset['online_path'])
+        local_path_file = os.path.join(project_root, dataset['online_path'])
         i = 0
         while not is_file_consistent(local_path_file, dataset['md5']) and i < 3:
             if os.path.isfile(local_path_file):
+                local_file_size = os.path.getsize(local_path_file)
                 logging.info("MD5 codes differ. ")
-                logging.info("The file size of the downloaded file is %s." %
-                             utils.sizeof_fmt(os.path.getsize(local_path_file))
-                             )
+                logging.info("The file size of the downloaded file is %s.",
+                             utils.sizeof_fmt(local_file_size))
             logging.info("Download the file '%s'...", dataset['online_path'])
             urllib.urlretrieve(dataset['url'], local_path_file)
             i += 1
