@@ -273,6 +273,7 @@ def analyze_results(translation_csv, what_evaluated_file, evaluation_file, n,
 
 
 def main(model_folder, aset='test', n=3, merge=True):
+    """Main part of the test script."""
     PROJECT_ROOT = utils.get_project_root()
 
     if aset == 'test':
@@ -327,6 +328,7 @@ def is_valid_file(parser, arg):
 
 
 def get_parser():
+    """Return the parser object for this script."""
     from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter
     parser = ArgumentParser(description=__doc__,
                             formatter_class=ArgumentDefaultsHelpFormatter)
